//                                                                    -*-c++-*-
// $Id: Masses.h,v 2.8 2007/05/09 14:33:51 sirca Exp $

#ifndef _MASSES_H_
#define _MASSES_H_

#include "FourVector/FourVector.h"

/** @name Masses and Particles

    The files Masses.h and Masses.cc define the particle masses. To
    identify the particles the class Particle extends the FourVector class.
*/
//@{
/// Particle with ID, Mass, Width and FourVector
class Particle : public FourVector {
private:
  int id;
  static int lastid;
  static Particle * first;
  Particle *next;
protected:
  const char *name;
  double mass;
  double width;
  int    charge;
  FourVector polarization;
public:
  /// Creates a new particle, the id is incremented automatically
  Particle(const FourVector & FV = FourVector(), 
	   const FourVector & pol = FourVector());
  /// Creates a particle, the id is incremented automatically
  Particle(const char *name, int charge, double mass, double width=0);
  /// Compares two particles. Only the ID is compared, not the FourVector!
  int operator==(const class Particle) const;
  /// Copy the FourVector to the particles FourVector
  // Whith out this operator the class use the constructor and all the 
  // other information of the particle will be lost
  Particle operator=(FourVector);
  /// This is usually not needed
  int getID() const { return id; }
  /// find Particle in chain
  static Particle *find(const char *name);
  /// get the parameters
  const char *getName() const { return name; }
  /// get the parameters
  double getWidth(void) const { return width; }
  /// get the parameters
  double getMass(void) const { return mass; }
  /// get the parameters
  int getCharge(void) const { return charge; }
  /// get the polarization or 4-Spin of the particle
  FourVector getPolarization(void) const {return polarization;}
  /// get the Spin of the particle
  Momentum getSpin(void) const;
  /// Set the momentum of the Particle. Mass is already known.
  void setMomentum(double px, double py, double pz);
  /// Set the Spin of the Particle
  Particle setSpin(const Momentum &s);
  /// Makes a Lorentz transformation to transport the particle to the RS where the reference FourVector is at rest
  Particle Lorentz(const FourVector& reference);
  /// Rotate the particle into the frame where the Z axis will point to the given direction
  Particle rotate(const Momentum& direction) const ;
  /// Rotate the particle into the frame where the given direction points to the old Z axis
  Particle rotateTo(const Momentum& direction) const ;
  /// IOStream output operator
  friend std::ostream& operator<<(std::ostream&, Particle);
};
//@}

// Particles
// From "Review of Particle Physics",
// R.M. Barnett et al., Phys. Rev. D 54 (1996) 1

const double m_electron =  0.00051099907;
const double m_mu =        0.105658389;
const double m_pi0 =       0.1349764;
const double m_pion =      0.13956995;
const double m_eta =       0.54745;
const double m_proton =    0.93827231;
const double m_neutron =   0.93956563;
const double m_deuteron =  1.87561339;

const double m_e_sqr = m_electron*m_electron;

// Resonances

const double m_rho =       0.7685;
const double m_omega =     0.78194;
const double m_Delta =     1.232;

// Nuclei
// Converted from "The 1995 update to the atomic mass evaluation"
// by G. Audi and A.H. Wapstra, Nucl. Phys. A 595 (1995) 409.
// (electron masses are subtracted)

const double m_H1	 =    0.93827231;
const double m_H1_nb1	 =    1.004;
const double m_H1_nb2	 =    1.044;
const double m_H1_nb3	 =    1.094;
const double m_H2	 =    1.87561339;
const double m_H3	 =    2.808922;
const double m_He3	 =    2.808392;
const double m_He4	 =    3.727380;
const double m_He5	 =    4.667836;
const double m_He6	 =    5.605538;
const double m_He8	 =    7.482531;
const double m_Li5	 =    4.667617;
const double m_Li6	 =    5.601519;
const double m_Li7	 =    6.533835;
const double m_Li8	 =    7.471368;
const double m_Li9	 =    8.406870;
const double m_Li11	 =   10.285700;
const double m_Be6	 =    5.605296;
const double m_Be7	 =    6.534186;
const double m_Be8	 =    7.454852;
const double m_Be9	 =    8.392752;
const double m_Be10	 =    9.325506;
const double m_Be11	 =   10.264568;
const double m_Be12	 =   11.200964;
const double m_Be14	 =   13.078759;
const double m_B8	 =    7.472321;
const double m_B9	 =    8.393310;
const double m_B10	 =    9.324439;
const double m_B11	 =   10.252551;
const double m_B12	 =   11.188746;
const double m_B13	 =   12.123433;
const double m_B14	 =   13.062029;
const double m_B15	 =   13.998827;
const double m_B17	 =   15.876565;
const double m_C8	 =    7.483983;
const double m_C9	 =    8.409297;
const double m_C10	 =    9.327576;
const double m_C11	 =   10.254022;
const double m_C12	 =   11.174866;
const double m_C13	 =   12.109485;
const double m_C14	 =   13.040874;
const double m_C15	 =   13.979222;
const double m_C16	 =   14.914537;
const double m_C17	 =   15.853374;
const double m_C18	 =   16.788756;
const double m_C19	 =   17.728159;
const double m_N11	 =   10.267821;
const double m_N12	 =   11.191693;
const double m_N13	 =   12.111195;
const double m_N14	 =   13.040207;
const double m_N15	 =   13.968939;
const double m_N16	 =   14.906016;
const double m_N17	 =   15.839697;
const double m_N18	 =   16.776438;
const double m_N19	 =   17.710676;
const double m_N20	 =   18.648076;
const double m_N21	 =   19.583036;
const double m_O13	 =   12.128449;
const double m_O14	 =   13.044839;
const double m_O15	 =   13.971182;
const double m_O16	 =   14.895084;
const double m_O17	 =   15.830506;
const double m_O18	 =   16.762028;
const double m_O19	 =   17.697638;
const double m_O20	 =   18.629595;
const double m_O21	 =   19.565354;
const double m_O22	 =   20.498071;
const double m_O23	 =   21.434898;
const double m_O24	 =   22.370750;
const double m_F16	 =   14.909990;
const double m_F17	 =   15.832756;
const double m_F18	 =   16.763172;
const double m_F19	 =   17.692306;
const double m_F20	 =   18.625270;
const double m_F21	 =   19.556734;
const double m_F22	 =   20.491070;
const double m_F23	 =   21.423100;
const double m_F24	 =   22.358809;
const double m_F25	 =   23.294025;
const double m_Ne17	 =   15.846779;
const double m_Ne18	 =   16.767095;
const double m_Ne19	 =   17.695033;
const double m_Ne20	 =   18.617734;
const double m_Ne21	 =   19.550539;
const double m_Ne22	 =   20.479741;
const double m_Ne23	 =   21.414106;
const double m_Ne24	 =   22.344806;
const double m_Ne25	 =   23.280189;
const double m_Ne26	 =   24.214172;
const double m_Ne27	 =   25.152330;
const double m_Na19	 =   17.705700;
const double m_Na20	 =   18.631110;
const double m_Na21	 =   19.553575;
const double m_Na22	 =   20.482072;
const double m_Na23	 =   21.409219;
const double m_Na24	 =   22.341825;
const double m_Na25	 =   23.272380;
const double m_Na26	 =   24.206329;
const double m_Na27	 =   25.139145;
const double m_Na28	 =   26.075186;
const double m_Na29	 =   27.010333;
const double m_Na30	 =   27.947803;
const double m_Na31	 =   28.883367;
const double m_Na32	 =   29.820501;
const double m_Na33	 =   30.759201;
const double m_Mg20	 =   18.641325;
const double m_Mg21	 =   19.566160;
const double m_Mg22	 =   20.486346;
const double m_Mg23	 =   21.412765;
const double m_Mg24	 =   22.335798;
const double m_Mg25	 =   23.268033;
const double m_Mg26	 =   24.196506;
const double m_Mg27	 =   25.129628;
const double m_Mg28	 =   26.060690;
const double m_Mg29	 =   26.996542;
const double m_Mg30	 =   27.929815;
const double m_Mg31	 =   28.866977;
const double m_Mg32	 =   29.800891;
const double m_Al23	 =   21.424494;
const double m_Al24	 =   22.349166;
const double m_Al25	 =   23.271799;
const double m_Al26	 =   24.199999;
const double m_Al27	 =   25.126507;
const double m_Al28	 =   26.058347;
const double m_Al29	 =   26.988477;
const double m_Al30	 =   27.922314;
const double m_Al31	 =   28.854727;
const double m_Al32	 =   29.790113;
const double m_Al33	 =   30.724165;
const double m_Al34	 =   31.661302;
const double m_Si25	 =   23.284029;
const double m_Si26	 =   24.204554;
const double m_Si27	 =   25.130808;
const double m_Si28	 =   26.053194;
const double m_Si29	 =   26.984286;
const double m_Si30	 =   27.913243;
const double m_Si31	 =   28.846221;
const double m_Si32	 =   29.776583;
const double m_Si33	 =   30.711666;
const double m_Si34	 =   31.643696;
const double m_Si35	 =   32.580787;
const double m_Si36	 =   33.514241;
const double m_P27	 =   25.141929;
const double m_P28	 =   26.067015;
const double m_P29	 =   26.988718;
const double m_P30	 =   27.916964;
const double m_P31	 =   28.844218;
const double m_P32	 =   29.775848;
const double m_P33	 =   30.705310;
const double m_P34	 =   31.638584;
const double m_P35	 =   32.569779;
const double m_P36	 =   33.505880;
const double m_P37	 =   34.438630;
const double m_P38	 =   35.374653;
const double m_P39	 =   36.307964;
const double m_S29	 =   27.002000;
const double m_S30	 =   27.922591;
const double m_S31	 =   28.849103;
const double m_S32	 =   29.773626;
const double m_S33	 =   30.704550;
const double m_S34	 =   31.632699;
const double m_S35	 =   32.565279;
const double m_S36	 =   33.494956;
const double m_S37	 =   34.430218;
const double m_S38	 =   35.361747;
const double m_S39	 =   36.296941;
const double m_S40	 =   37.228747;
const double m_Cl31	 =   28.860572;
const double m_Cl32	 =   29.785801;
const double m_Cl33	 =   30.709622;
const double m_Cl34	 =   31.637679;
const double m_Cl35	 =   32.564601;
const double m_Cl36	 =   33.495587;
const double m_Cl37	 =   34.424841;
const double m_Cl38	 =   35.358299;
const double m_Cl39	 =   36.289791;
const double m_Cl40	 =   37.223528;
const double m_Cl41	 =   38.155241;
const double m_Cl42	 =   39.089087;
const double m_Cl43	 =   40.021539;
const double m_Ar33	 =   30.720733;
const double m_Ar34	 =   31.643231;
const double m_Ar35	 =   32.570055;
const double m_Ar36	 =   33.494367;
const double m_Ar37	 =   34.425144;
const double m_Ar38	 =   35.352871;
const double m_Ar39	 =   36.285839;
const double m_Ar40	 =   37.215535;
const double m_Ar41	 =   38.149002;
const double m_Ar42	 =   39.079141;
const double m_Ar43	 =   40.013080;
const double m_Ar44	 =   40.944290;
const double m_Ar45	 =   41.878327;
const double m_Ar46	 =   42.809820;
const double m_K35	 =   32.581425;
const double m_K36	 =   33.506661;
const double m_K37	 =   34.430782;
const double m_K38	 =   35.358273;
const double m_K39	 =   36.284763;
const double m_K40	 =   37.216529;
const double m_K41	 =   38.145999;
const double m_K42	 =   39.078031;
const double m_K43	 =   40.007954;
const double m_K44	 =   40.940231;
const double m_K45	 =   41.870927;
const double m_K46	 =   42.803611;
const double m_K47	 =   43.734827;
const double m_K48	 =   44.669894;
const double m_K49	 =   45.603193;
const double m_K50	 =   46.539654;
const double m_Ca37	 =   34.441909;
const double m_Ca38	 =   35.364505;
const double m_Ca39	 =   36.290782;
const double m_Ca40	 =   37.214707;
const double m_Ca41	 =   38.145910;
const double m_Ca42	 =   39.073995;
const double m_Ca43	 =   40.005627;
const double m_Ca44	 =   40.934061;
const double m_Ca45	 =   41.866212;
const double m_Ca46	 =   42.795384;
const double m_Ca47	 =   43.727673;
const double m_Ca48	 =   44.657293;
const double m_Ca49	 =   45.591712;
const double m_Ca50	 =   46.524925;
const double m_Sc40	 =   37.228515;
const double m_Sc41	 =   38.151894;
const double m_Sc42	 =   39.079910;
const double m_Sc43	 =   40.007337;
const double m_Sc44	 =   40.937203;
const double m_Sc45	 =   41.865444;
const double m_Sc46	 =   42.796249;
const double m_Sc47	 =   43.725170;
const double m_Sc48	 =   44.656504;
const double m_Sc49	 =   45.585938;
const double m_Sc50	 =   46.519447;
const double m_Sc51	 =   47.452261;
const double m_Ti42	 =   39.086399;
const double m_Ti43	 =   40.013693;
const double m_Ti44	 =   40.936960;
const double m_Ti45	 =   41.866995;
const double m_Ti46	 =   42.793371;
const double m_Ti47	 =   43.724059;
const double m_Ti48	 =   44.651998;
const double m_Ti49	 =   45.583422;
const double m_Ti50	 =   46.512048;
const double m_Ti51	 =   47.445241;
const double m_Ti52	 =   48.376999;
const double m_Ti53	 =   49.311132;
const double m_V46	 =   42.799912;
const double m_V47	 =   43.726476;
const double m_V48	 =   44.655500;
const double m_V49	 =   45.583512;
const double m_V50	 =   46.513745;
const double m_V51	 =   47.442260;
const double m_V52	 =   48.374514;
const double m_V53	 =   49.305601;
const double m_V54	 =   50.239054;
const double m_V55	 =   51.171287;
const double m_Cr46	 =   42.807004;
const double m_Cr47	 =   43.733417;
const double m_Cr48	 =   44.656648;
const double m_Cr49	 =   45.585632;
const double m_Cr50	 =   46.512198;
const double m_Cr51	 =   47.442502;
const double m_Cr52	 =   48.370028;
const double m_Cr53	 =   49.301654;
const double m_Cr54	 =   50.231501;
const double m_Cr55	 =   51.164820;
const double m_Cr56	 =   52.096129;
const double m_Cr57	 =   53.030519;
const double m_Mn49	 =   45.592836;
const double m_Mn50	 =   46.519320;
const double m_Mn51	 =   47.445198;
const double m_Mn52	 =   48.374229;
const double m_Mn53	 =   49.301740;
const double m_Mn54	 =   50.232367;
const double m_Mn55	 =   51.161706;
const double m_Mn56	 =   52.094001;
const double m_Mn57	 =   53.024916;
const double m_Mn58	 =   53.957993;
const double m_Mn59	 =   54.889917;
const double m_Fe50	 =   46.526959;
const double m_Fe51	 =   47.452707;
const double m_Fe52	 =   48.376090;
const double m_Fe53	 =   49.304972;
const double m_Fe54	 =   50.231159;
const double m_Fe55	 =   51.161427;
const double m_Fe56	 =   52.089795;
const double m_Fe57	 =   53.021715;
const double m_Fe58	 =   53.951236;
const double m_Fe59	 =   54.884220;
const double m_Fe60	 =   55.814966;
const double m_Fe61	 =   56.748950;
const double m_Fe62	 =   57.680464;
const double m_Co53	 =   49.312763;
const double m_Co54	 =   50.238891;
const double m_Co55	 =   51.164367;
const double m_Co56	 =   52.093850;
const double m_Co57	 =   53.022040;
const double m_Co58	 =   53.953032;
const double m_Co59	 =   54.882144;
const double m_Co60	 =   55.814218;
const double m_Co61	 =   56.744461;
const double m_Co62	 =   57.677423;
const double m_Co63	 =   58.608508;
const double m_Co64	 =   59.542050;
const double m_Ni54	 =   50.247179;
const double m_Ni55	 =   51.172550;
const double m_Ni56	 =   52.095474;
const double m_Ni57	 =   53.024793;
const double m_Ni58	 =   53.952140;
const double m_Ni59	 =   54.882706;
const double m_Ni60	 =   55.810883;
const double m_Ni61	 =   56.742629;
const double m_Ni62	 =   57.671597;
const double m_Ni63	 =   58.604325;
const double m_Ni64	 =   59.534233;
const double m_Ni65	 =   60.467700;
const double m_Ni66	 =   61.398288;
const double m_Ni67	 =   62.332069;
const double m_Ni68	 =   63.263820;
const double m_Cu58	 =   53.960192;
const double m_Cu59	 =   54.886994;
const double m_Cu60	 =   55.816499;
const double m_Cu61	 =   56.744355;
const double m_Cu62	 =   57.675034;
const double m_Cu63	 =   58.603747;
const double m_Cu64	 =   59.535397;
const double m_Cu65	 =   60.465052;
const double m_Cu66	 =   61.397552;
const double m_Cu67	 =   62.328000;
const double m_Cu68	 =   63.261253;
const double m_Cu69	 =   64.192549;
const double m_Cu70	 =   65.126823;
const double m_Zn60	 =   55.820146;
const double m_Zn61	 =   56.749481;
const double m_Zn62	 =   57.676150;
const double m_Zn63	 =   58.606603;
const double m_Zn64	 =   59.534307;
const double m_Zn65	 =   60.465893;
const double m_Zn66	 =   61.394399;
const double m_Zn67	 =   62.326912;
const double m_Zn68	 =   63.256280;
const double m_Zn69	 =   64.189363;
const double m_Zn70	 =   65.119713;
const double m_Zn71	 =   66.053445;
const double m_Zn72	 =   66.984133;
const double m_Zn73	 =   67.918345;
const double m_Zn74	 =   68.849540;
const double m_Zn75	 =   69.784276;
const double m_Zn76	 =   70.716195;
const double m_Zn77	 =   71.651129;
const double m_Ga63	 =   58.611612;
const double m_Ga64	 =   59.540961;
const double m_Ga65	 =   60.468637;
const double m_Ga66	 =   61.399063;
const double m_Ga67	 =   62.327402;
const double m_Ga68	 =   63.258690;
const double m_Ga69	 =   64.187946;
const double m_Ga70	 =   65.119857;
const double m_Ga71	 =   66.050119;
const double m_Ga72	 =   66.983164;
const double m_Ga73	 =   67.913541;
const double m_Ga74	 =   68.846685;
const double m_Ga75	 =   69.777769;
const double m_Ga76	 =   70.711524;
const double m_Ga77	 =   71.643347;
const double m_Ga78	 =   72.577054;
const double m_Ga79	 =   73.509722;
const double m_Ga80	 =   74.444637;
const double m_Ga81	 =   75.377216;
const double m_Ge64	 =   59.544860;
const double m_Ge65	 =   60.474368;
const double m_Ge66	 =   61.400652;
const double m_Ge67	 =   62.331114;
const double m_Ge68	 =   63.258285;
const double m_Ge69	 =   64.189662;
const double m_Ge70	 =   65.117690;
const double m_Ge71	 =   66.049840;
const double m_Ge72	 =   66.978653;
const double m_Ge73	 =   67.911436;
const double m_Ge74	 =   68.840806;
const double m_Ge75	 =   69.773866;
const double m_Ge76	 =   70.704003;
const double m_Ge77	 =   71.637496;
const double m_Ge78	 =   72.568343;
const double m_Ge79	 =   73.502211;
const double m_Ge80	 =   74.433746;
const double m_Ge81	 =   75.368385;
const double m_Ge82	 =   76.300559;
const double m_As68	 =   63.265874;
const double m_As69	 =   64.193164;
const double m_As70	 =   65.123399;
const double m_As71	 =   66.051342;
const double m_As72	 =   66.982499;
const double m_As73	 =   67.911266;
const double m_As74	 =   68.842857;
const double m_As75	 =   69.772179;
const double m_As76	 =   70.704416;
const double m_As77	 =   71.634283;
const double m_As78	 =   72.566878;
const double m_As79	 =   73.497552;
const double m_As80	 =   74.430565;
const double m_As81	 =   75.361644;
const double m_As82	 =   76.295348;
const double m_As83	 =   77.227285;
const double m_Se69	 =   64.199437;
const double m_Se72	 =   66.982323;
const double m_Se73	 =   67.913495;
const double m_Se74	 =   68.840993;
const double m_Se75	 =   69.772531;
const double m_Se76	 =   70.700943;
const double m_Se77	 =   71.633090;
const double m_Se78	 =   72.562157;
const double m_Se79	 =   73.494760;
const double m_Se80	 =   74.424412;
const double m_Se81	 =   75.357277;
const double m_Se82	 =   76.287567;
const double m_Se83	 =   77.221314;
const double m_Se84	 =   78.152199;
const double m_Se85	 =   79.087215;
const double m_Se86	 =   80.020597;
const double m_Se87	 =   80.956049;
const double m_Se88	 =   81.890248;
const double m_Br72	 =   66.990553;
const double m_Br73	 =   67.917668;
const double m_Br74	 =   68.847389;
const double m_Br75	 =   69.775050;
const double m_Br76	 =   70.705395;
const double m_Br77	 =   71.633944;
const double m_Br78	 =   72.565220;
const double m_Br79	 =   73.494098;
const double m_Br80	 =   74.425772;
const double m_Br81	 =   75.355181;
const double m_Br82	 =   76.287153;
const double m_Br83	 =   77.217134;
const double m_Br84	 =   78.149862;
const double m_Br85	 =   79.080522;
const double m_Br86	 =   80.014987;
const double m_Br87	 =   80.948263;
const double m_Br88	 =   81.882883;
const double m_Br89	 =   82.816540;
const double m_Br90	 =   83.751991;
const double m_Br91	 =   84.686587;
const double m_Br92	 =   85.623009;
const double m_Kr72	 =   66.995082;
const double m_Kr73	 =   67.923804;
const double m_Kr74	 =   68.850014;
const double m_Kr75	 =   69.779436;
const double m_Kr76	 =   70.706194;
const double m_Kr77	 =   71.636495;
const double m_Kr78	 =   72.564001;
const double m_Kr79	 =   73.495213;
const double m_Kr80	 =   74.423256;
const double m_Kr81	 =   75.354950;
const double m_Kr82	 =   76.283550;
const double m_Kr83	 =   77.215651;
const double m_Kr84	 =   78.144696;
const double m_Kr85	 =   79.077141;
const double m_Kr86	 =   80.006850;
const double m_Kr87	 =   80.940900;
const double m_Kr88	 =   81.873412;
const double m_Kr89	 =   82.807874;
const double m_Kr90	 =   83.741130;
const double m_Kr91	 =   84.676274;
const double m_Kr92	 =   85.610293;
const double m_Kr93	 =   86.546550;
const double m_Rb74	 =   68.859947;
const double m_Rb75	 =   69.785945;
const double m_Rb76	 =   70.714181;
const double m_Rb77	 =   71.641330;
const double m_Rb78	 =   72.570714;
const double m_Rb79	 =   73.498348;
const double m_Rb80	 =   74.428466;
const double m_Rb81	 =   75.356676;
const double m_Rb82	 =   76.287438;
const double m_Rb83	 =   77.216049;
const double m_Rb84	 =   78.146866;
const double m_Rb85	 =   79.075943;
const double m_Rb86	 =   80.006857;
const double m_Rb87	 =   80.936504;
const double m_Rb88	 =   81.869987;
const double m_Rb89	 =   82.802377;
const double m_Rb90	 =   83.736227;
const double m_Rb91	 =   84.669328;
const double m_Rb92	 =   85.603795;
const double m_Rb93	 =   86.537439;
const double m_Rb94	 =   87.473008;
const double m_Rb95	 =   88.407215;
const double m_Rb96	 =   89.343334;
const double m_Rb97	 =   90.277677;
const double m_Rb98	 =   91.213234;
const double m_Rb99	 =   92.148190;
const double m_Sr77	 =   71.647670;
const double m_Sr78	 =   72.573964;
const double m_Sr79	 =   73.503156;
const double m_Sr80	 =   74.429823;
const double m_Sr81	 =   75.360095;
const double m_Sr82	 =   76.287108;
const double m_Sr83	 =   77.217814;
const double m_Sr84	 =   78.145461;
const double m_Sr85	 =   79.076497;
const double m_Sr86	 =   80.004572;
const double m_Sr87	 =   80.935709;
const double m_Sr88	 =   81.864162;
const double m_Sr89	 =   82.797369;
const double m_Sr90	 =   83.729129;
const double m_Sr91	 =   84.662926;
const double m_Sr92	 =   85.595184;
const double m_Sr93	 =   86.529466;
const double m_Sr94	 =   87.462206;
const double m_Sr95	 =   88.397425;
const double m_Sr96	 =   89.331083;
const double m_Sr97	 =   90.266739;
const double m_Sr98	 =   91.200397;
const double m_Sr99	 =   92.136403;
const double m_Y81	 =   75.365095;
const double m_Y82	 =   76.294413;
const double m_Y83	 =   77.221771;
const double m_Y84	 =   78.151436;
const double m_Y85	 =   79.079241;
const double m_Y86	 =   80.009301;
const double m_Y87	 =   80.937060;
const double m_Y88	 =   81.867274;
const double m_Y89	 =   82.795363;
const double m_Y90	 =   83.728072;
const double m_Y91	 =   84.659708;
const double m_Y92	 =   85.592733;
const double m_Y93	 =   86.524819;
const double m_Y94	 =   87.458187;
const double m_Y95	 =   88.390827;
const double m_Y96	 =   89.325185;
const double m_Y97	 =   90.258760;
const double m_Y98	 =   91.194062;
const double m_Y99	 =   92.127806;
const double m_Y100	 =   93.062209;
const double m_Y102	 =   94.930599;
const double m_Zr81	 =   75.371744;
const double m_Zr82	 =   76.297902;
const double m_Zr83	 =   77.227128;
const double m_Zr85	 =   79.083423;
const double m_Zr86	 =   80.010266;
const double m_Zr87	 =   80.940218;
const double m_Zr88	 =   81.867436;
const double m_Zr89	 =   82.797685;
const double m_Zr90	 =   83.725281;
const double m_Zr91	 =   84.657652;
const double m_Zr92	 =   85.588583;
const double m_Zr93	 =   86.521414;
const double m_Zr94	 =   87.452760;
const double m_Zr95	 =   88.385863;
const double m_Zr96	 =   89.317574;
const double m_Zr97	 =   90.251560;
const double m_Zr98	 =   91.184727;
const double m_Zr99	 =   92.119728;
const double m_Zr100	 =   93.052388;
const double m_Zr101	 =   93.987029;
const double m_Zr102	 =   94.920238;
const double m_Nb86	 =   80.017733;
const double m_Nb87	 =   80.944872;
const double m_Nb89	 =   82.801465;
const double m_Nb90	 =   83.730881;
const double m_Nb91	 =   84.658394;
const double m_Nb92	 =   85.590077;
const double m_Nb93	 =   86.520812;
const double m_Nb94	 =   87.453150;
const double m_Nb95	 =   88.384227;
const double m_Nb96	 =   89.316900;
const double m_Nb97	 =   90.248391;
const double m_Nb98	 =   91.181966;
const double m_Nb99	 =   92.114659;
const double m_Nb100	 =   93.048542;
const double m_Nb101	 =   93.981033;
const double m_Nb102	 =   94.915122;
const double m_Nb103	 =   95.847645;
const double m_Nb104	 =   96.782230;
const double m_Nb105	 =   97.715098;
const double m_Mo87	 =   80.950849;
const double m_Mo88	 =   81.877338;
const double m_Mo89	 =   82.806529;
const double m_Mo90	 =   83.732859;
const double m_Mo91	 =   84.662317;
const double m_Mo92	 =   85.589210;
const double m_Mo93	 =   86.520706;
const double m_Mo94	 =   87.450594;
const double m_Mo95	 =   88.382790;
const double m_Mo96	 =   89.313202;
const double m_Mo97	 =   90.245946;
const double m_Mo98	 =   91.176869;
const double m_Mo99	 =   92.110510;
const double m_Mo100	 =   93.041786;
const double m_Mo101	 =   93.975953;
const double m_Mo102	 =   94.907401;
const double m_Mo103	 =   95.841604;
const double m_Mo104	 =   96.773614;
const double m_Mo105	 =   97.708102;
const double m_Mo106	 =   98.640679;
const double m_Mo107	 =   99.575489;
const double m_Tc90	 =   83.741309;
const double m_Tc91	 =   84.668026;
const double m_Tc92	 =   85.596569;
const double m_Tc93	 =   86.523396;
const double m_Tc94	 =   87.454338;
const double m_Tc95	 =   88.383970;
const double m_Tc96	 =   89.315664;
const double m_Tc97	 =   90.245755;
const double m_Tc98	 =   91.178042;
const double m_Tc99	 =   92.108641;
const double m_Tc100	 =   93.041443;
const double m_Tc101	 =   93.972617;
const double m_Tc102	 =   94.905880;
const double m_Tc103	 =   95.837343;
const double m_Tc104	 =   96.770948;
const double m_Tc105	 =   97.702641;
const double m_Tc106	 =   98.636648;
const double m_Tc107	 =   99.568818;
const double m_Tc108	 =  100.503478;
const double m_Ru93	 =   86.529222;
const double m_Ru94	 =   87.455414;
const double m_Ru95	 =   88.386026;
const double m_Ru96	 =   89.314899;
const double m_Ru97	 =   90.246353;
const double m_Ru98	 =   91.175735;
const double m_Ru99	 =   92.107837;
const double m_Ru100	 =   93.037729;
const double m_Ru101	 =   93.970493;
const double m_Ru102	 =   94.900839;
const double m_Ru103	 =   95.834172;
const double m_Ru104	 =   96.764834;
const double m_Ru105	 =   97.698490;
const double m_Ru106	 =   98.629590;
const double m_Ru107	 =   99.563487;
const double m_Ru108	 =  100.495247;
const double m_Ru109	 =  101.429545;
const double m_Ru110	 =  102.361751;
const double m_Rh95	 =   88.390625;
const double m_Rh96	 =   89.320834;
const double m_Rh97	 =   90.249365;
const double m_Rh98	 =   91.180281;
const double m_Rh99	 =   92.109368;
const double m_Rh100	 =   93.040848;
const double m_Rh101	 =   93.970523;
const double m_Rh102	 =   94.902650;
const double m_Rh103	 =   95.832898;
const double m_Rh104	 =   96.765464;
const double m_Rh105	 =   97.696062;
const double m_Rh106	 =   98.629039;
const double m_Rh107	 =   99.560036;
const double m_Rh108	 =  100.493375;
const double m_Rh109	 =  101.424874;
const double m_Rh110	 =  102.358430;
const double m_Pd97	 =   90.253644;
const double m_Pd98	 =   91.181637;
const double m_Pd99	 =   92.112244;
const double m_Pd100	 =   93.040699;
const double m_Pd101	 =   93.971992;
const double m_Pd102	 =   94.900989;
const double m_Pd103	 =   95.832930;
const double m_Pd104	 =   96.762512;
const double m_Pd105	 =   97.694984;
const double m_Pd106	 =   98.624987;
const double m_Pd107	 =   99.558014;
const double m_Pd108	 =  100.488359;
const double m_Pd109	 =  101.421771;
const double m_Pd110	 =  102.352519;
const double m_Pd111	 =  103.286334;
const double m_Pd112	 =  104.217521;
const double m_Pd113	 =  105.151659;
const double m_Pd114	 =  106.083352;
const double m_Pd115	 =  107.017937;
const double m_Pd116	 =  107.949874;
const double m_Pd118	 =  109.817358;
const double m_Ag99	 =   92.117163;
const double m_Ag100	 =   93.047234;
const double m_Ag101	 =   93.975685;
const double m_Ag102	 =   94.906432;
const double m_Ag103	 =   95.835106;
const double m_Ag104	 =   96.766280;
const double m_Ag105	 =   97.695818;
const double m_Ag106	 =   98.627441;
const double m_Ag107	 =   99.557470;
const double m_Ag108	 =  100.489766;
const double m_Ag109	 =  101.420144;
const double m_Ag110	 =  102.352901;
const double m_Ag111	 =  103.283635;
const double m_Ag112	 =  104.216722;
const double m_Ag113	 =  105.147808;
const double m_Ag114	 =  106.081391;
const double m_Ag115	 =  107.012842;
const double m_Ag116	 =  107.946756;
const double m_Ag117	 =  108.878553;
const double m_Ag118	 =  109.812747;
const double m_Ag119	 =  110.745251;
const double m_Ag120	 =  111.679653;
const double m_Ag121	 =  112.612137;
const double m_Cd100	 =   93.050599;
const double m_Cd101	 =   93.980651;
const double m_Cd102	 =   94.908508;
const double m_Cd103	 =   95.838737;
const double m_Cd104	 =   96.766905;
const double m_Cd105	 =   97.698045;
const double m_Cd106	 =   98.626736;
const double m_Cd107	 =   99.558376;
const double m_Cd108	 =  100.487606;
const double m_Cd109	 =  101.419848;
const double m_Cd110	 =  102.349497;
const double m_Cd111	 =  103.282087;
const double m_Cd112	 =  104.212255;
const double m_Cd113	 =  105.145280;
const double m_Cd114	 =  106.075803;
const double m_Cd115	 =  107.009228;
const double m_Cd116	 =  107.940093;
const double m_Cd117	 =  108.873882;
const double m_Cd118	 =  109.805093;
const double m_Cd119	 =  110.739390;
const double m_Cd120	 =  111.670817;
const double m_Cd121	 =  112.605226;
const double m_Cd124	 =  115.404058;
const double m_In104	 =   96.774303;
const double m_In105	 =   97.702383;
const double m_In106	 =   98.632749;
const double m_In107	 =   99.561291;
const double m_In108	 =  100.492252;
const double m_In109	 =  101.421356;
const double m_In110	 =  102.352864;
const double m_In111	 =  103.282442;
const double m_In112	 =  104.214330;
const double m_In113	 =  105.144453;
const double m_In114	 =  106.076744;
const double m_In115	 =  107.007271;
const double m_In116	 =  107.940052;
const double m_In117	 =  108.870853;
const double m_In118	 =  109.804061;
const double m_In119	 =  110.735082;
const double m_In120	 =  111.668546;
const double m_In121	 =  112.599935;
const double m_In122	 =  113.533692;
const double m_In123	 =  114.465337;
const double m_In124	 =  115.399381;
const double m_In125	 =  116.331271;
const double m_In126	 =  117.265433;
const double m_In127	 =  118.197746;
const double m_In128	 =  119.131873;
const double m_In129	 =  120.064753;
const double m_In130	 =  120.999225;
const double m_In131	 =  121.932501;
const double m_In132	 =  122.869726;
const double m_Sn107	 =   99.565786;
const double m_Sn108	 =  100.493833;
const double m_Sn109	 =  101.424695;
const double m_Sn110	 =  102.352991;
const double m_Sn111	 =  103.284376;
const double m_Sn112	 =  104.213155;
const double m_Sn113	 =  105.144978;
const double m_Sn114	 =  106.074244;
const double m_Sn115	 =  107.006264;
const double m_Sn116	 =  107.936266;
const double m_Sn117	 =  108.868887;
const double m_Sn118	 =  109.799127;
const double m_Sn119	 =  110.732207;
const double m_Sn120	 =  111.662665;
const double m_Sn121	 =  112.596060;
const double m_Sn122	 =  113.526812;
const double m_Sn123	 =  114.460432;
const double m_Sn124	 =  115.391510;
const double m_Sn125	 =  116.325342;
const double m_Sn126	 =  117.256715;
const double m_Sn127	 =  118.190721;
const double m_Sn128	 =  119.122387;
const double m_Sn129	 =  120.056587;
const double m_Sn130	 =  120.988465;
const double m_Sn131	 =  121.922817;
const double m_Sn132	 =  122.855080;
const double m_Sn133	 =  123.792228;
const double m_Sn134	 =  124.728053;
const double m_Sb112	 =  104.219699;
const double m_Sb113	 =  105.148383;
const double m_Sb114	 =  106.079615;
const double m_Sb115	 =  107.008783;
const double m_Sb116	 =  107.940462;
const double m_Sb117	 =  108.870133;
const double m_Sb118	 =  109.802272;
const double m_Sb119	 =  110.732290;
const double m_Sb120	 =  111.664835;
const double m_Sb121	 =  112.595159;
const double m_Sb122	 =  113.527918;
const double m_Sb123	 =  114.458518;
const double m_Sb124	 =  115.391616;
const double m_Sb125	 =  116.322468;
const double m_Sb126	 =  117.255826;
const double m_Sb127	 =  118.187009;
const double m_Sb128	 =  119.120602;
const double m_Sb129	 =  120.052080;
const double m_Sb130	 =  120.985807;
const double m_Sb131	 =  121.917674;
const double m_Sb132	 =  122.851466;
const double m_Sb133	 =  123.783727;
const double m_Sb134	 =  124.720172;
const double m_Sb135	 =  125.655967;
const double m_Te108	 =  100.509132;
const double m_Te109	 =  101.438735;
const double m_Te111	 =  103.295822;
const double m_Te112	 =  104.223535;
const double m_Te115	 =  107.012911;
const double m_Te116	 =  107.941463;
const double m_Te117	 =  108.873157;
const double m_Te118	 =  109.802035;
const double m_Te119	 =  110.734072;
const double m_Te120	 =  111.663342;
const double m_Te121	 =  112.595683;
const double m_Te122	 =  113.525424;
const double m_Te123	 =  114.458060;
const double m_Te124	 =  115.388201;
const double m_Te125	 =  116.321190;
const double m_Te126	 =  117.251642;
const double m_Te127	 =  118.184917;
const double m_Te128	 =  119.115707;
const double m_Te129	 =  120.049190;
const double m_Te130	 =  120.980337;
const double m_Te131	 =  121.913973;
const double m_Te132	 =  122.845469;
const double m_Te133	 =  123.779213;
const double m_Te134	 =  124.711267;
const double m_Te135	 =  125.647336;
const double m_Te136	 =  126.582232;
const double m_Te137	 =  127.518590;
const double m_I116	 =  107.948697;
const double m_I117	 =  108.877316;
const double m_I118	 =  109.808556;
const double m_I119	 =  110.737075;
const double m_I120	 =  111.668446;
const double m_I121	 =  112.597442;
const double m_I122	 =  113.529147;
const double m_I123	 =  114.458783;
const double m_I124	 =  115.390849;
const double m_I125	 =  116.320865;
const double m_I126	 =  117.253286;
const double m_I127	 =  118.183709;
const double m_I128	 =  119.116448;
const double m_I129	 =  120.047181;
const double m_I130	 =  120.980246;
const double m_I131	 =  121.911228;
const double m_I132	 =  122.844465;
const double m_I133	 =  123.775784;
const double m_I134	 =  124.709206;
const double m_I135	 =  125.640863;
const double m_I136	 =  126.576646;
const double m_I137	 =  127.511138;
const double m_I138	 =  128.446834;
const double m_I139	 =  129.381784;
const double m_Xe113	 =  105.169211;
const double m_Xe117	 =  108.883248;
const double m_Xe118	 =  109.811022;
const double m_Xe119	 =  110.741569;
const double m_Xe120	 =  111.669895;
const double m_Xe121	 =  112.600676;
const double m_Xe122	 =  113.529526;
const double m_Xe123	 =  114.460948;
const double m_Xe124	 =  115.390044;
const double m_Xe125	 =  116.322007;
const double m_Xe126	 =  117.251517;
const double m_Xe127	 =  118.183860;
const double m_Xe128	 =  119.113818;
const double m_Xe129	 =  120.046476;
const double m_Xe130	 =  120.976786;
const double m_Xe131	 =  121.909746;
const double m_Xe132	 =  122.840377;
const double m_Xe133	 =  123.773502;
const double m_Xe134	 =  124.704520;
const double m_Xe135	 =  125.637704;
const double m_Xe136	 =  126.569209;
const double m_Xe137	 =  127.504749;
const double m_Xe138	 =  128.438503;
const double m_Xe139	 =  129.374467;
const double m_Xe140	 =  130.308615;
const double m_Xe141	 =  131.244777;
const double m_Xe142	 =  132.179118;
const double m_Cs116	 =  107.962746;
const double m_Cs117	 =  108.890259;
const double m_Cs118	 =  109.819811;
const double m_Cs119	 =  110.747408;
const double m_Cs120	 =  111.677326;
const double m_Cs121	 =  112.605565;
const double m_Cs122	 =  113.536070;
const double m_Cs123	 =  114.464647;
const double m_Cs124	 =  115.395448;
const double m_Cs125	 =  116.324594;
const double m_Cs126	 =  117.255831;
const double m_Cs127	 =  118.185434;
const double m_Cs128	 =  119.117236;
const double m_Cs129	 =  120.047161;
const double m_Cs130	 =  120.979254;
const double m_Cs131	 =  121.909588;
const double m_Cs132	 =  122.841985;
const double m_Cs133	 =  123.772564;
const double m_Cs134	 =  124.705238;
const double m_Cs135	 =  125.636042;
const double m_Cs136	 =  126.568778;
const double m_Cs137	 =  127.500066;
const double m_Cs138	 =  128.435218;
const double m_Cs139	 =  129.368899;
const double m_Cs140	 =  130.304044;
const double m_Cs141	 =  131.238116;
const double m_Cs142	 =  132.173567;
const double m_Cs143	 =  133.107891;
const double m_Cs144	 =  134.043761;
const double m_Cs145	 =  134.978386;
const double m_Cs146	 =  135.914327;
const double m_Ba119	 =  110.754983;
const double m_Ba121	 =  112.611856;
const double m_Ba124	 =  115.397585;
const double m_Ba125	 =  116.328643;
const double m_Ba126	 =  117.256993;
const double m_Ba127	 =  118.188373;
const double m_Ba128	 =  119.117247;
const double m_Ba129	 =  120.049081;
const double m_Ba130	 =  120.978374;
const double m_Ba131	 =  121.910447;
const double m_Ba132	 =  122.840195;
const double m_Ba133	 =  123.772570;
const double m_Ba134	 =  124.702668;
const double m_Ba135	 =  125.635261;
const double m_Ba136	 =  126.565719;
const double m_Ba137	 =  127.498379;
const double m_Ba138	 =  128.429333;
const double m_Ba139	 =  129.364175;
const double m_Ba140	 =  130.297313;
const double m_Ba141	 =  131.232353;
const double m_Ba142	 =  132.165749;
const double m_Ba143	 =  133.101127;
const double m_Ba144	 =  134.034786;
const double m_Ba145	 =  134.969990;
const double m_Ba146	 =  135.904450;
const double m_La128	 =  119.123386;
const double m_La129	 =  120.052290;
const double m_La131	 =  121.912896;
const double m_La132	 =  122.844392;
const double m_La133	 =  123.774289;
const double m_La134	 =  124.705871;
const double m_La135	 =  125.635950;
const double m_La136	 =  126.568078;
const double m_La137	 =  127.498468;
const double m_La138	 =  128.430560;
const double m_La139	 =  129.361347;
const double m_La140	 =  130.295752;
const double m_La141	 =  131.228629;
const double m_La142	 =  132.163027;
const double m_La143	 =  133.096370;
const double m_La144	 =  134.031155;
const double m_La145	 =  134.964556;
const double m_La146	 =  135.899834;
const double m_La147	 =  136.833302;
const double m_La148	 =  137.768869;
const double m_Ce131	 =  121.916405;
const double m_Ce134	 =  124.705860;
const double m_Ce135	 =  125.637465;
const double m_Ce136	 =  126.567094;
const double m_Ce137	 =  127.499179;
const double m_Ce138	 =  128.429004;
const double m_Ce139	 =  129.361114;
const double m_Ce140	 =  130.291479;
const double m_Ce141	 =  131.225616;
const double m_Ce142	 =  132.158013;
const double m_Ce143	 =  133.092433;
const double m_Ce144	 =  134.025103;
const double m_Ce145	 =  134.959937;
const double m_Ce146	 =  135.892793;
const double m_Ce147	 =  136.827846;
const double m_Ce148	 =  137.761096;
const double m_Ce149	 =  138.696218;
const double m_Ce150	 =  139.629516;
const double m_Pr135	 =  125.640674;
const double m_Pr136	 =  126.571710;
const double m_Pr137	 =  127.501370;
const double m_Pr138	 =  128.432930;
const double m_Pr139	 =  129.362732;
const double m_Pr140	 =  130.294356;
const double m_Pr141	 =  131.224525;
const double m_Pr142	 =  132.158247;
const double m_Pr143	 =  133.090461;
const double m_Pr144	 =  134.024273;
const double m_Pr145	 =  134.956891;
const double m_Pr146	 =  135.891255;
const double m_Pr147	 =  136.824045;
const double m_Pr148	 =  137.758525;
const double m_Pr149	 =  138.691517;
const double m_Pr150	 =  139.625995;
const double m_Pr151	 =  140.558638;
const double m_Nd136	 =  126.573410;
const double m_Nd137	 =  127.504549;
const double m_Nd139	 =  129.365008;
const double m_Nd140	 =  130.294067;
const double m_Nd141	 =  131.225837;
const double m_Nd142	 =  132.155574;
const double m_Nd143	 =  133.089016;
const double m_Nd144	 =  134.020765;
const double m_Nd145	 =  134.954575;
const double m_Nd146	 =  135.886575;
const double m_Nd147	 =  136.820849;
const double m_Nd148	 =  137.753082;
const double m_Nd149	 =  138.687609;
const double m_Nd150	 =  139.619794;
const double m_Nd151	 =  140.554026;
const double m_Nd152	 =  141.486319;
const double m_Nd154	 =  143.353779;
const double m_Pm139	 =  129.369002;
const double m_Pm140	 =  130.299604;
const double m_Pm141	 =  131.229053;
const double m_Pm142	 =  132.159937;
const double m_Pm143	 =  133.089546;
const double m_Pm144	 =  134.022585;
const double m_Pm145	 =  134.954227;
const double m_Pm146	 =  135.887536;
const double m_Pm147	 =  136.819442;
const double m_Pm148	 =  137.753110;
const double m_Pm149	 =  138.685407;
const double m_Pm150	 =  139.619370;
const double m_Pm151	 =  140.551072;
const double m_Pm152	 =  141.484698;
const double m_Pm153	 =  142.416772;
const double m_Pm154	 =  143.350533;
const double m_Sm137	 =  127.515084;
const double m_Sm139	 =  129.373653;
const double m_Sm140	 =  130.302063;
const double m_Sm141	 =  131.233071;
const double m_Sm142	 =  132.161515;
const double m_Sm143	 =  133.092478;
const double m_Sm144	 =  134.021524;
const double m_Sm145	 =  134.954332;
const double m_Sm146	 =  135.885483;
const double m_Sm147	 =  136.818707;
const double m_Sm148	 =  137.750131;
const double m_Sm149	 =  138.683825;
const double m_Sm150	 =  139.615405;
const double m_Sm151	 =  140.549374;
const double m_Sm152	 =  141.480682;
const double m_Sm153	 =  142.414380;
const double m_Sm154	 =  143.345978;
const double m_Sm155	 =  144.279736;
const double m_Sm156	 =  145.212060;
const double m_Sm157	 =  146.146189;
const double m_Eu140	 =  130.310022;
const double m_Eu141	 =  131.238538;
const double m_Eu142	 =  132.168648;
const double m_Eu143	 =  133.097242;
const double m_Eu144	 =  134.027328;
const double m_Eu145	 =  134.956481;
const double m_Eu146	 =  135.888850;
const double m_Eu147	 =  136.819917;
const double m_Eu148	 =  137.752727;
const double m_Eu149	 =  138.684009;
const double m_Eu150	 =  139.617154;
const double m_Eu151	 =  140.548786;
const double m_Eu152	 =  141.482045;
const double m_Eu153	 =  142.413061;
const double m_Eu154	 =  143.346184;
const double m_Eu155	 =  144.277599;
const double m_Eu156	 =  145.210827;
const double m_Eu157	 =  146.142944;
const double m_Eu158	 =  147.076695;
const double m_Eu159	 =  148.009347;
const double m_Gd143	 =  133.102741;
const double m_Gd145	 =  134.961025;
const double m_Gd146	 =  135.889369;
const double m_Gd147	 =  136.821593;
const double m_Gd148	 =  137.752175;
const double m_Gd149	 =  138.684812;
const double m_Gd150	 =  139.615672;
const double m_Gd151	 =  140.548740;
const double m_Gd152	 =  141.479716;
const double m_Gd153	 =  142.413034;
const double m_Gd154	 =  143.343705;
const double m_Gd155	 =  144.276836;
const double m_Gd156	 =  145.207865;
const double m_Gd157	 =  146.141070;
const double m_Gd158	 =  147.072699;
const double m_Gd159	 =  148.006321;
const double m_Gd160	 =  148.938435;
const double m_Gd161	 =  149.872366;
const double m_Gd162	 =  150.805085;
const double m_Tb146	 =  135.897125;
const double m_Tb147	 =  136.825691;
const double m_Tb148	 =  137.757429;
const double m_Tb149	 =  138.687939;
const double m_Tb150	 =  139.619817;
const double m_Tb151	 =  140.550794;
const double m_Tb152	 =  141.483195;
const double m_Tb153	 =  142.414092;
const double m_Tb154	 =  143.346756;
const double m_Tb155	 =  144.277146;
const double m_Tb156	 =  145.209798;
const double m_Tb157	 =  146.140619;
const double m_Tb158	 =  147.073408;
const double m_Tb159	 =  148.004839;
const double m_Tb160	 =  148.938030;
const double m_Tb161	 =  149.869899;
const double m_Tb162	 =  150.803180;
const double m_Tb163	 =  151.735754;
const double m_Tb164	 =  152.669767;
const double m_Dy147	 =  136.831553;
const double m_Dy148	 =  137.759600;
const double m_Dy149	 =  138.691240;
const double m_Dy150	 =  139.621100;
const double m_Dy151	 =  140.553153;
const double m_Dy152	 =  141.483282;
const double m_Dy153	 =  142.415752;
const double m_Dy154	 =  143.345999;
const double m_Dy155	 =  144.278729;
const double m_Dy156	 =  145.208854;
const double m_Dy157	 =  146.141450;
const double m_Dy158	 =  147.071960;
const double m_Dy159	 =  148.004694;
const double m_Dy160	 =  148.935684;
const double m_Dy161	 =  149.868795;
const double m_Dy162	 =  150.800164;
const double m_Dy163	 =  151.733458;
const double m_Dy164	 =  152.665366;
const double m_Dy165	 =  153.599216;
const double m_Dy166	 =  154.531738;
const double m_Dy167	 =  155.465883;
const double m_Ho151	 =  140.557766;
const double m_Ho152	 =  141.489316;
const double m_Ho153	 =  142.419371;
const double m_Ho154	 =  143.351239;
const double m_Ho155	 =  144.281320;
const double m_Ho157	 =  146.143479;
const double m_Ho158	 =  147.075679;
const double m_Ho159	 =  148.006021;
const double m_Ho160	 =  148.938463;
const double m_Ho161	 =  149.869143;
const double m_Ho162	 =  150.801793;
const double m_Ho163	 =  151.732950;
const double m_Ho164	 =  152.665842;
const double m_Ho165	 =  153.597419;
const double m_Ho166	 =  154.530741;
const double m_Ho167	 =  155.463022;
const double m_Ho168	 =  156.396724;
const double m_Ho169	 =  157.329496;
const double m_Ho170	 =  158.263549;
const double m_Er152	 =  141.491915;
const double m_Er153	 =  142.423423;
const double m_Er154	 =  143.352760;
const double m_Er155	 =  144.284652;
const double m_Er156	 =  145.214107;
const double m_Er157	 =  146.146468;
const double m_Er159	 =  148.008278;
const double m_Er160	 =  148.938281;
const double m_Er161	 =  149.870634;
const double m_Er162	 =  150.800986;
const double m_Er163	 =  151.733649;
const double m_Er164	 =  152.664368;
const double m_Er165	 =  153.597284;
const double m_Er166	 =  154.528375;
const double m_Er167	 =  155.461504;
const double m_Er168	 =  156.393299;
const double m_Er169	 =  157.326861;
const double m_Er170	 =  158.259168;
const double m_Er171	 =  159.193052;
const double m_Er172	 =  160.125782;
const double m_Tm153	 =  142.429371;
const double m_Tm155	 =  144.289718;
const double m_Tm156	 =  145.221040;
const double m_Tm157	 =  146.150438;
const double m_Tm159	 =  148.011613;
const double m_Tm160	 =  148.943370;
const double m_Tm161	 =  149.873287;
const double m_Tm162	 =  150.805314;
const double m_Tm163	 =  151.735577;
const double m_Tm164	 =  152.667820;
const double m_Tm165	 =  153.598365;
const double m_Tm166	 =  154.530903;
const double m_Tm167	 =  155.461742;
const double m_Tm168	 =  156.394467;
const double m_Tm169	 =  157.325999;
const double m_Tm170	 =  158.258972;
const double m_Tm171	 =  159.191051;
const double m_Tm172	 =  160.124380;
const double m_Tm173	 =  161.056996;
const double m_Tm174	 =  161.990879;
const double m_Tm175	 =  162.923928;
const double m_Tm176	 =  163.858364;
const double m_Yb156	 =  145.224106;
const double m_Yb157	 =  146.155425;
const double m_Yb158	 =  147.084311;
const double m_Yb163	 =  151.738436;
const double m_Yb165	 =  153.600616;
const double m_Yb166	 =  154.530696;
const double m_Yb167	 =  155.463185;
const double m_Yb168	 =  156.393699;
const double m_Yb169	 =  157.326397;
const double m_Yb170	 =  158.257493;
const double m_Yb171	 =  159.190443;
const double m_Yb172	 =  160.121989;
const double m_Yb173	 =  161.055187;
const double m_Yb174	 =  161.987288;
const double m_Yb175	 =  162.921032;
const double m_Yb176	 =  163.853733;
const double m_Yb177	 =  164.787732;
const double m_Yb178	 =  165.720518;
const double m_Lu165	 =  153.604025;
const double m_Lu166	 =  154.535665;
const double m_Lu167	 =  155.465804;
const double m_Lu168	 =  156.397663;
const double m_Lu169	 =  157.328179;
const double m_Lu170	 =  158.260441;
const double m_Lu171	 =  159.191411;
const double m_Lu172	 =  160.123998;
const double m_Lu173	 =  161.055347;
const double m_Lu174	 =  161.988152;
const double m_Lu175	 =  162.920051;
const double m_Lu176	 =  163.853328;
const double m_Lu177	 =  164.785822;
const double m_Lu178	 =  165.719362;
const double m_Lu179	 =  166.652135;
const double m_Lu180	 =  167.586010;
const double m_Hf160	 =  148.956389;
const double m_Hf161	 =  149.887527;
const double m_Hf169	 =  157.330938;
const double m_Hf172	 =  160.123837;
const double m_Hf174	 =  161.987367;
const double m_Hf175	 =  162.920224;
const double m_Hf176	 =  163.851625;
const double m_Hf177	 =  164.784812;
const double m_Hf178	 =  165.716752;
const double m_Hf179	 =  166.650218;
const double m_Hf180	 =  167.582396;
const double m_Hf181	 =  168.516266;
const double m_Hf182	 =  169.449115;
const double m_Hf183	 =  170.383383;
const double m_Hf184	 =  171.316663;
const double m_Ta172	 =  160.128246;
const double m_Ta174	 =  161.990701;
const double m_Ta176	 =  163.854224;
const double m_Ta177	 =  164.785467;
const double m_Ta178	 =  165.718153;
const double m_Ta179	 =  166.649818;
const double m_Ta180	 =  167.582739;
const double m_Ta181	 =  168.514728;
const double m_Ta182	 =  169.448231;
const double m_Ta183	 =  170.380862;
const double m_Ta184	 =  171.314812;
const double m_Ta185	 =  172.247750;
const double m_Ta186	 =  173.182030;
const double m_W164	 =  152.689048;
const double m_W165	 =  153.619939;
const double m_W166	 =  154.548344;
const double m_W178	 =  165.717733;
const double m_W179	 =  166.650367;
const double m_W180	 =  167.581520;
const double m_W181	 =  168.514405;
const double m_W182	 =  169.445906;
const double m_W183	 =  170.379281;
const double m_W184	 =  171.311435;
const double m_W185	 =  172.245247;
const double m_W186	 =  173.177618;
const double m_W187	 =  174.111717;
const double m_W188	 =  175.044449;
const double m_W189	 =  175.979134;
const double m_W190	 =  176.911809;
const double m_Re178	 =  165.721882;
const double m_Re179	 =  166.652566;
const double m_Re180	 =  167.584812;
const double m_Re181	 =  168.515632;
const double m_Re182	 =  169.448195;
const double m_Re183	 =  170.379326;
const double m_Re184	 =  171.312407;
const double m_Re185	 =  172.244303;
const double m_Re186	 =  173.177689;
const double m_Re187	 =  174.109895;
const double m_Re188	 =  175.043589;
const double m_Re189	 =  175.976123;
const double m_Re190	 =  176.910028;
const double m_Re191	 =  177.842740;
const double m_Os169	 =  157.353036;
const double m_Os170	 =  158.281264;
const double m_Os178	 =  165.723697;
const double m_Os181	 =  168.518111;
const double m_Os182	 =  169.448592;
const double m_Os184	 =  171.311864;
const double m_Os185	 =  172.244805;
const double m_Os186	 =  173.176108;
const double m_Os187	 =  174.109381;
const double m_Os188	 =  175.040958;
const double m_Os189	 =  175.974603;
const double m_Os190	 =  176.906377;
const double m_Os191	 =  177.840184;
const double m_Os192	 =  178.772191;
const double m_Os193	 =  179.706172;
const double m_Os194	 =  180.638627;
const double m_Os195	 =  181.572864;
const double m_Os196	 =  182.505754;
const double m_Ir181	 =  168.521669;
const double m_Ir182	 =  169.453615;
const double m_Ir184	 =  171.315915;
const double m_Ir186	 =  173.179428;
const double m_Ir187	 =  174.110373;
const double m_Ir188	 =  175.043256;
const double m_Ir189	 =  175.974624;
const double m_Ir190	 =  176.907866;
const double m_Ir191	 =  177.839359;
const double m_Ir192	 =  178.772727;
const double m_Ir193	 =  179.704520;
const double m_Ir194	 =  180.638019;
const double m_Ir195	 =  181.570353;
const double m_Ir196	 =  182.504086;
const double m_Ir197	 =  183.436751;
const double m_Pt173	 =  161.086769;
const double m_Pt174	 =  162.014828;
const double m_Pt182	 =  169.456029;
const double m_Pt185	 =  172.250034;
const double m_Pt186	 =  173.180297;
const double m_Pt188	 =  175.043252;
const double m_Pt189	 =  175.976084;
const double m_Pt190	 =  176.906738;
const double m_Pt191	 =  177.839867;
const double m_Pt192	 =  178.770756;
const double m_Pt193	 =  179.704066;
const double m_Pt194	 =  180.635261;
const double m_Pt195	 =  181.568722;
const double m_Pt196	 =  182.500366;
const double m_Pt197	 =  183.434085;
const double m_Pt198	 =  184.366094;
const double m_Pt199	 =  185.300104;
const double m_Pt200	 =  186.232388;
const double m_Pt201	 =  187.166744;
const double m_Au185	 =  172.254230;
const double m_Au186	 =  173.185902;
const double m_Au190	 =  176.910669;
const double m_Au191	 =  177.841186;
const double m_Au192	 =  178.773761;
const double m_Au193	 =  179.704624;
const double m_Au194	 =  180.637243;
const double m_Au195	 =  181.568438;
const double m_Au196	 =  182.501361;
const double m_Au197	 =  183.432855;
const double m_Au198	 =  184.365908;
const double m_Au199	 =  185.297890;
const double m_Au200	 =  186.231219;
const double m_Au201	 =  187.163573;
const double m_Au202	 =  188.097068;
const double m_Au203	 =  189.029819;
const double m_Hg177	 =  164.820888;
const double m_Hg178	 =  165.748786;
const double m_Hg186	 =  173.188616;
const double m_Hg191	 =  177.843855;
const double m_Hg193	 =  179.706453;
const double m_Hg194	 =  180.636772;
const double m_Hg195	 =  181.569437;
const double m_Hg196	 =  182.500164;
const double m_Hg197	 =  183.432944;
const double m_Hg198	 =  184.364025;
const double m_Hg199	 =  185.296926;
const double m_Hg200	 =  186.228464;
const double m_Hg201	 =  187.161799;
const double m_Hg202	 =  188.093611;
const double m_Hg203	 =  189.027184;
const double m_Hg204	 =  189.959254;
const double m_Hg205	 =  190.893152;
const double m_Hg206	 =  191.825990;
const double m_Tl197	 =  183.434613;
const double m_Tl198	 =  184.366974;
const double m_Tl199	 =  185.297861;
const double m_Tl200	 =  186.230409;
const double m_Tl201	 =  187.161771;
const double m_Tl202	 =  188.094464;
const double m_Tl203	 =  189.026181;
const double m_Tl204	 =  189.959091;
const double m_Tl205	 =  190.891110;
const double m_Tl206	 =  191.824172;
const double m_Tl207	 =  192.756889;
const double m_Tl208	 =  193.692665;
const double m_Tl209	 =  194.627275;
const double m_Tl210	 =  195.563162;
const double m_Pb190	 =  176.921694;
const double m_Pb199	 =  185.300233;
const double m_Pb200	 =  186.230708;
const double m_Pb201	 =  187.163163;
const double m_Pb202	 =  188.094003;
const double m_Pb203	 =  189.026644;
const double m_Pb204	 =  189.957816;
const double m_Pb205	 =  190.890650;
const double m_Pb206	 =  191.822127;
const double m_Pb207	 =  192.754955;
const double m_Pb208	 =  193.687153;
const double m_Pb209	 =  194.622782;
const double m_Pb210	 =  195.557163;
const double m_Pb211	 =  196.492903;
const double m_Pb212	 =  197.427337;
const double m_Pb214	 =  199.297695;
const double m_Bi197	 =  183.442346;
const double m_Bi198	 =  184.373924;
const double m_Bi199	 =  185.304070;
const double m_Bi200	 =  186.236090;
const double m_Bi201	 =  187.166494;
const double m_Bi202	 =  188.098644;
const double m_Bi203	 =  189.029387;
const double m_Bi204	 =  189.961754;
const double m_Bi205	 =  190.892847;
const double m_Bi206	 =  191.825374;
const double m_Bi207	 =  192.756842;
const double m_Bi208	 =  193.689521;
const double m_Bi209	 =  194.621627;
const double m_Bi210	 =  195.556588;
const double m_Bi211	 =  196.491020;
const double m_Bi212	 =  197.426252;
const double m_Bi213	 =  198.360637;
const double m_Bi214	 =  199.296159;
const double m_Bi215	 =  200.230573;
const double m_Po194	 =  180.656061;
const double m_Po203	 =  189.033109;
const double m_Po204	 =  189.963574;
const double m_Po205	 =  190.895867;
const double m_Po206	 =  191.826709;
const double m_Po207	 =  192.759241;
const double m_Po208	 =  193.690411;
const double m_Po209	 =  194.623009;
const double m_Po210	 =  195.554915;
const double m_Po211	 =  196.489930;
const double m_Po212	 =  197.423487;
const double m_Po213	 =  198.358699;
const double m_Po214	 =  199.292376;
const double m_Po215	 =  200.227810;
const double m_Po216	 =  201.161624;
const double m_Po218	 =  203.031189;
const double m_At201	 =  187.176199;
const double m_At202	 =  188.107658;
const double m_At203	 =  189.037660;
const double m_At204	 =  189.969541;
const double m_At205	 =  190.899894;
const double m_At206	 =  191.831912;
const double m_At207	 =  192.762640;
const double m_At208	 =  193.694885;
const double m_At209	 =  194.625985;
const double m_At210	 =  195.558385;
const double m_At211	 =  196.490205;
const double m_At212	 =  197.424730;
const double m_At213	 =  198.358261;
const double m_At214	 =  199.292956;
const double m_At215	 =  200.226578;
const double m_At216	 =  201.161582;
const double m_At217	 =  202.095220;
const double m_At218	 =  203.030414;
const double m_At219	 =  203.964344;
const double m_Rn207	 =  192.766740;
const double m_Rn208	 =  193.697214;
const double m_Rn209	 =  194.629403;
const double m_Rn210	 =  195.560248;
const double m_Rn211	 =  196.492586;
const double m_Rn212	 =  197.424177;
const double m_Rn213	 =  198.358633;
const double m_Rn214	 =  199.291504;
const double m_Rn215	 =  200.226149;
const double m_Rn216	 =  201.159068;
const double m_Rn217	 =  202.093968;
const double m_Rn218	 =  203.027019;
const double m_Rn219	 =  203.962136;
const double m_Rn220	 =  204.895409;
const double m_Rn222	 =  206.764160;
const double m_Fr205	 =  190.910634;
const double m_Fr206	 =  191.841964;
const double m_Fr207	 =  192.771942;
const double m_Fr208	 =  193.703692;
const double m_Fr209	 =  194.634051;
const double m_Fr210	 =  195.565995;
const double m_Fr211	 =  196.496680;
const double m_Fr212	 =  197.428795;
const double m_Fr213	 =  198.360270;
const double m_Fr214	 =  199.294354;
const double m_Fr215	 =  200.227126;
const double m_Fr216	 =  201.161286;
const double m_Fr217	 =  202.094111;
const double m_Fr218	 =  203.028350;
const double m_Fr219	 =  203.961407;
const double m_Fr220	 =  204.895763;
const double m_Fr221	 =  205.829058;
const double m_Fr222	 =  206.763624;
const double m_Fr223	 =  207.697155;
const double m_Fr224	 =  208.631915;
const double m_Fr225	 =  209.565618;
const double m_Fr226	 =  210.500593;
const double m_Fr227	 =  211.434406;
const double m_Ra211	 =  196.501166;
const double m_Ra212	 =  197.431626;
const double m_Ra213	 =  198.363644;
const double m_Ra214	 =  199.294901;
const double m_Ra215	 =  200.228830;
const double m_Ra216	 =  201.161083;
const double m_Ra217	 =  202.095174;
const double m_Ra218	 =  203.027430;
const double m_Ra219	 =  203.961667;
const double m_Ra220	 =  204.894043;
const double m_Ra221	 =  205.828232;
const double m_Ra222	 =  206.761081;
const double m_Ra223	 =  207.695495;
const double m_Ra224	 =  208.628578;
const double m_Ra225	 =  209.563242;
const double m_Ra226	 =  210.496411;
const double m_Ra227	 =  211.431415;
const double m_Ra228	 =  212.364673;
const double m_Ra229	 =  213.299666;
const double m_Ra230	 =  214.233270;
const double m_Ac209	 =  194.645747;
const double m_Ac210	 =  195.576951;
const double m_Ac211	 =  196.506947;
const double m_Ac212	 =  197.438593;
const double m_Ac213	 =  198.368935;
const double m_Ac214	 =  199.300726;
const double m_Ac215	 =  200.231809;
const double m_Ac216	 =  201.165418;
const double m_Ac217	 =  202.097482;
const double m_Ac218	 =  203.031112;
const double m_Ac219	 =  203.963332;
const double m_Ac220	 =  204.897013;
const double m_Ac221	 =  205.829275;
const double m_Ac222	 =  206.762868;
const double m_Ac223	 =  207.695570;
const double m_Ac224	 =  208.629470;
const double m_Ac225	 =  209.562373;
const double m_Ac226	 =  210.496540;
const double m_Ac227	 =  211.429578;
const double m_Ac228	 =  212.364116;
const double m_Ac229	 =  213.297395;
const double m_Ac230	 =  214.231772;
const double m_Ac231	 =  215.165620;
const double m_Ac232	 =  216.100347;
const double m_Th215	 =  200.236212;
const double m_Th216	 =  201.167077;
const double m_Th217	 =  202.100449;
const double m_Th218	 =  203.032131;
const double m_Th219	 =  203.965724;
const double m_Th220	 =  204.897416;
const double m_Th221	 =  205.831181;
const double m_Th222	 =  206.762939;
const double m_Th223	 =  207.696614;
const double m_Th224	 =  208.628727;
const double m_Th225	 =  209.562533;
const double m_Th226	 =  210.494912;
const double m_Th227	 =  211.429022;
const double m_Th228	 =  212.361478;
const double m_Th229	 =  213.295789;
const double m_Th230	 =  214.228561;
const double m_Th231	 =  215.163009;
const double m_Th232	 =  216.096136;
const double m_Th233	 =  217.030915;
const double m_Th234	 =  217.964290;
const double m_Th235	 =  218.899425;
const double m_Pa216	 =  201.174073;
const double m_Pa223	 =  207.699055;
const double m_Pa224	 =  208.632087;
const double m_Pa225	 =  209.564047;
const double m_Pa226	 =  210.497235;
const double m_Pa227	 =  211.429530;
const double m_Pa228	 =  212.363115;
const double m_Pa229	 =  213.295589;
const double m_Pa230	 =  214.229360;
const double m_Pa231	 =  215.162108;
const double m_Pa232	 =  216.096120;
const double m_Pa233	 =  217.029159;
const double m_Pa234	 =  217.963506;
const double m_Pa235	 =  218.896988;
const double m_Pa236	 =  219.831499;
const double m_Pa237	 =  220.765289;
const double m_Pa238	 =  221.699911;
const double m_U226	 =  210.498034;
const double m_U227	 =  211.431206;
const double m_U228	 =  212.362911;
const double m_U229	 =  213.296389;
const double m_U230	 =  214.228285;
const double m_U231	 =  215.161979;
const double m_U232	 =  216.094272;
const double m_U233	 =  217.028078;
const double m_U234	 =  217.960800;
const double m_U235	 =  218.895067;
const double m_U236	 =  219.828088;
const double m_U237	 =  220.762528;
const double m_U238	 =  221.695940;
const double m_U239	 =  222.630699;
const double m_U240	 =  223.564334;
const double m_Np229	 =  213.298440;
const double m_Np230	 =  214.231393;
const double m_Np231	 =  215.163279;
const double m_Np233	 =  217.028596;
const double m_Np234	 =  217.962098;
const double m_Np235	 =  218.894680;
const double m_Np236	 =  219.828507;
const double m_Np237	 =  220.761498;
const double m_Np238	 =  221.695576;
const double m_Np239	 =  222.628925;
const double m_Np240	 =  223.563435;
const double m_Np241	 =  224.496864;
const double m_Pu232	 =  216.097007;
const double m_Pu233	 =  217.030185;
const double m_Pu234	 =  217.961975;
const double m_Pu235	 =  218.895311;
const double m_Pu236	 =  219.827519;
const double m_Pu237	 =  220.761208;
const double m_Pu238	 =  221.693773;
const double m_Pu239	 =  222.627692;
const double m_Pu240	 =  223.560724;
const double m_Pu241	 =  224.495048;
const double m_Pu242	 =  225.428305;
const double m_Pu243	 =  226.362836;
const double m_Pu244	 =  227.296380;
const double m_Pu245	 =  228.231173;
const double m_Pu246	 =  229.164958;
const double m_Am237	 =  220.762156;
const double m_Am238	 =  221.695520;
const double m_Am239	 =  222.627984;
const double m_Am240	 =  223.561592;
const double m_Am241	 =  224.494516;
const double m_Am242	 =  225.428545;
const double m_Am243	 =  226.361743;
const double m_Am244	 =  227.295945;
const double m_Am245	 =  228.229457;
const double m_Am246	 =  229.164047;
const double m_Cm238	 =  221.695977;
const double m_Cm240	 =  223.561297;
const double m_Cm241	 =  224.494773;
const double m_Cm242	 =  225.427369;
const double m_Cm243	 =  226.361241;
const double m_Cm244	 =  227.294006;
const double m_Cm245	 =  228.228052;
const double m_Cm246	 =  229.161160;
const double m_Cm247	 =  230.095569;
const double m_Cm248	 =  231.028922;
const double m_Cm249	 =  231.963774;
const double m_Cm250	 =  232.897507;
const double m_Cm251	 =  233.832660;
const double m_Bk243	 =  226.362238;
const double m_Bk244	 =  227.295751;
const double m_Bk245	 =  228.228351;
const double m_Bk246	 =  229.161999;
const double m_Bk247	 =  230.095013;
const double m_Bk249	 =  231.962362;
const double m_Bk250	 =  232.896959;
const double m_Bk251	 =  233.830729;
const double m_Cf242	 =  225.430873;
const double m_Cf244	 =  227.296006;
const double m_Cf246	 =  229.161611;
const double m_Cf247	 =  230.095148;
const double m_Cf248	 =  231.027747;
const double m_Cf249	 =  231.961727;
const double m_Cf250	 =  232.894668;
const double m_Cf251	 =  233.829125;
const double m_Cf252	 =  234.762519;
const double m_Cf253	 =  235.697280;
const double m_Cf254	 =  236.630814;
const double m_Es251	 =  233.828990;
const double m_Es252	 =  234.763268;
const double m_Es253	 =  235.696482;
const double m_Es254	 =  236.630955;
const double m_Es255	 =  237.564545;
const double m_Fm246	 =  229.166627;
const double m_Fm248	 =  231.031388;
const double m_Fm250	 =  232.896548;
const double m_Fm251	 =  233.829953;
const double m_Fm252	 =  234.762280;
const double m_Fm253	 =  235.696304;
const double m_Fm254	 =  236.629356;
const double m_Fm255	 =  237.563745;
const double m_Fm256	 =  238.496926;
const double m_Fm257	 =  239.431524;
const double m_Md255	 =  237.564277;
const double m_Md256	 =  238.498545;
const double m_Md257	 =  239.431419;
const double m_Md258	 =  240.365606;
const double m_No252	 =  234.767318;
const double m_No254	 =  236.632154;
const double m_No255	 =  237.565775;
const double m_No256	 =  238.498241;
const double m_No257	 =  239.432136;
const double m_Rf256	 =  238.503650;
const double m_Sg260	 =  242.240953;
const double m_Hs264	 =  245.978924;

extern const Particle P_gamma;
extern const Particle P_electron;
extern const Particle P_positron;
extern const Particle P_muminus;
extern const Particle P_muplus;
extern const Particle P_piminus;
extern const Particle P_eta;
extern const Particle P_pi0;
extern const Particle P_piplus;
extern const Particle P_proton;
extern const Particle P_neutron;
extern const Particle P_deuteron;
extern const Particle P_triton;
extern const Particle P_H1;
extern const Particle P_H2;
extern const Particle P_H3;
extern const Particle P_He3;
extern const Particle P_He4;
extern const Particle P_Li6;
extern const Particle P_Li7;
extern const Particle P_Be7;
extern const Particle P_Be9;
extern const Particle P_Be10;
extern const Particle P_B10;
extern const Particle P_B11;
extern const Particle P_B12;
extern const Particle P_C11;
extern const Particle P_C12;
extern const Particle P_C13;
extern const Particle P_C14;
extern const Particle P_N12;
extern const Particle P_N14;
extern const Particle P_N15;
extern const Particle P_O15;
extern const Particle P_O16;
extern const Particle P_Al27;
extern const Particle P_Ta181;
extern const Particle P_Deltam;
extern const Particle P_Delta0;
extern const Particle P_Deltap;
extern const Particle P_Deltapp;
extern const Particle P_rhominus;
extern const Particle P_rho0;
extern const Particle P_rhoplus;
extern const Particle P_rho600;
extern const Particle P_rho700;

#endif /* _MASSES_H_ */


